( cd usr/bin ; rm -rf gs )
( cd usr/bin ; ln -sf gsx gs )
( cd usr/lib ; rm -rf libgs.so.8 )
( cd usr/lib ; ln -sf libgs.so.8.64 libgs.so.8 )
( cd usr/lib ; rm -rf libgs.so )
( cd usr/lib ; ln -sf libgs.so.8.64 libgs.so )
( cd usr/share/man/man1 ; rm -rf ps2pdf13.1.gz )
( cd usr/share/man/man1 ; ln -sf ps2pdf.1.gz ps2pdf13.1.gz )
( cd usr/share/man/man1 ; rm -rf ps2pdf12.1.gz )
( cd usr/share/man/man1 ; ln -sf ps2pdf.1.gz ps2pdf12.1.gz )
( cd usr/share/man/man1 ; rm -rf eps2eps.1.gz )
( cd usr/share/man/man1 ; ln -sf ps2ps.1.gz eps2eps.1.gz )
( cd usr/share/man/de/man1 ; rm -rf eps2eps.1 )
( cd usr/share/man/de/man1 ; ln -sf ps2ps.1 eps2eps.1 )
( cd usr/share/man/de/man1 ; rm -rf ps2pdf12.1 )
( cd usr/share/man/de/man1 ; ln -sf ps2pdf.1 ps2pdf12.1 )
( cd usr/share/man/de/man1 ; rm -rf ps2pdf13.1 )
( cd usr/share/man/de/man1 ; ln -sf ps2pdf.1 ps2pdf13.1 )
